"""Registry types."""
from enum import unique

from backports.strenum import StrEnum

from .common import BaseId, BaseModel


class BaseObjectId(BaseId):
    """Registry object identifier base class."""


class BaseObjectHistoryId(BaseId):
    """Registry object history identifier base class."""


class ContactId(BaseObjectId):
    """Contact id."""


class ContactHistoryId(BaseObjectHistoryId):
    """Contact history id."""


class ContactRef(BaseModel):
    """Contact reference info."""

    id: ContactId
    handle: str
    name: str = ""
    organization: str = ""


class DomainId(BaseObjectId):
    """Domain id."""


class DomainHistoryId(BaseObjectHistoryId):
    """Domain history id."""


class DomainRef(BaseModel):
    """Domain reference info."""

    id: DomainId
    fqdn: str


class KeysetId(BaseObjectId):
    """Keyset id."""


class KeysetHistoryId(BaseObjectHistoryId):
    """Keyset history id."""


class KeysetRef(BaseModel):
    """Keyset reference info."""

    id: KeysetId
    handle: str


class NssetId(BaseObjectId):
    """Nsset id."""


class NssetHistoryId(BaseObjectHistoryId):
    """Nsset history id."""


class NssetRef(BaseModel):
    """Nsset reference info."""

    id: NssetId
    handle: str


class RegistrarId(BaseId):
    """Registrar identifier."""


class RepresentativeId(BaseObjectId):
    """Contact representative id."""


class RepresentativeHistoryId(BaseObjectHistoryId):
    """Contact representative history id."""


@unique
class RegistryObjectType(StrEnum):
    """Registry object type."""

    CONTACT = "contact"
    DOMAIN = "domain"
    KEYSET = "keyset"
    NSSET = "nsset"
